@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2017 Hive Solutions Lda.
+# Copyright (c) 2008-2018 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -78,3 +78,13 @@ class ConfigTest(unittest.TestCase):
         result = appier.conf("HEIGHT")
 
         self.assertEqual(result, None)
+
+    def test_none(self):
+        appier.conf_s("AGE", None)
+        result = appier.conf("AGE", cast = int)
+
+        self.assertEqual(result, None)
+
+        result = appier.conf("HEIGHT", cast = int)
+
+        self.assertEqual(result, None)
